import {useCallback, useState} from "react";
import {
    Form,
    DatePicker,
} from 'antd-mobile'
import dayjs from 'dayjs'
import {CloseCircleFill} from 'antd-mobile-icons'

const DatePickerItem = (props) => {
    const [pickerVisible, setPickerVisible] = useState(false)
    const {fieldName, labelName} = props
    const labelRenderer = useCallback((type, data) => {
        switch (type) {
            case 'year':
                return data + '年'
            case 'month':
                return data + '月'
            case 'day':
                return data + '日'
            case 'hour':
                return data + '时'
            case 'minute':
                return data + '分'
            case 'second':
                return data + '秒'
            default:
                return data
        }
    }, [])
    return (
        <Form.Item
            noStyle
            shouldUpdate={(prevValues, curValues) =>
                prevValues.fieldName !== curValues.fieldName
            }
        >
            {({getFieldValue, setFieldsValue}) => (
                <Form.Item
                    name={fieldName}
                    label={labelName}
                    trigger='onConfirm'
                    arrow={
                        getFieldValue(fieldName) ? (
                            <CloseCircleFill
                                style={{
                                    color: 'var(--adm-color-light)',
                                    fontSize: 14,
                                }}
                                onClick={e => {
                                    e.stopPropagation()
                                    setFieldsValue({fieldName: null})
                                }}
                            />
                        ) : (
                            true
                        )
                    }
                    onClick={() => {
                        setPickerVisible(true)
                    }}
                >
                    <DatePicker
                        precision='minute'
                        visible={pickerVisible}
                        renderLabel={labelRenderer}
                        onClose={() => {
                            setPickerVisible(false)
                        }}
                    >
                        {value =>
                            value ? dayjs(value).format('YYYY-MM-DD HH:mm:ss') : '请选择日期'
                        }
                    </DatePicker>
                </Form.Item>
            )}
        </Form.Item>
    )
}
export default DatePickerItem;